"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Alexa_ASK_Skill_AuthenticationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    refresh_token: builtins.str
    client_secret: builtins.str
    client_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        refresh_token: builtins.str = ...,
        client_secret: builtins.str = ...,
        client_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "refresh_token", b"refresh_token", "resource_info", b"resource_info"]) -> None: ...

global___Alexa_ASK_Skill_AuthenticationConfiguration = Alexa_ASK_Skill_AuthenticationConfiguration

@typing_extensions.final
class Alexa_ASK_Skill_Overrides(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ManifestEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MANIFEST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def manifest(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        manifest: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["manifest", b"manifest", "resource_info", b"resource_info"]) -> None: ...

global___Alexa_ASK_Skill_Overrides = Alexa_ASK_Skill_Overrides

@typing_extensions.final
class Alexa_ASK_Skill_SkillPackage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_ROLE_FIELD_NUMBER: builtins.int
    S3_OBJECT_VERSION_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    OVERRIDES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket_role: builtins.str
    s3_object_version: builtins.str
    s3_bucket: builtins.str
    s3_key: builtins.str
    @property
    def overrides(self) -> global___Alexa_ASK_Skill_Overrides: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket_role: builtins.str = ...,
        s3_object_version: builtins.str = ...,
        s3_bucket: builtins.str = ...,
        s3_key: builtins.str = ...,
        overrides: global___Alexa_ASK_Skill_Overrides | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["overrides", b"overrides", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["overrides", b"overrides", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_bucket_role", b"s3_bucket_role", "s3_key", b"s3_key", "s3_object_version", b"s3_object_version"]) -> None: ...

global___Alexa_ASK_Skill_SkillPackage = Alexa_ASK_Skill_SkillPackage

@typing_extensions.final
class Alexa_ASK_Skill(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    VENDOR_ID_FIELD_NUMBER: builtins.int
    SKILL_PACKAGE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def authentication_configuration(self) -> global___Alexa_ASK_Skill_AuthenticationConfiguration: ...
    vendor_id: builtins.str
    @property
    def skill_package(self) -> global___Alexa_ASK_Skill_SkillPackage: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authentication_configuration: global___Alexa_ASK_Skill_AuthenticationConfiguration | None = ...,
        vendor_id: builtins.str = ...,
        skill_package: global___Alexa_ASK_Skill_SkillPackage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_configuration", b"authentication_configuration", "resource_info", b"resource_info", "skill_package", b"skill_package"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_configuration", b"authentication_configuration", "resource_info", b"resource_info", "skill_package", b"skill_package", "vendor_id", b"vendor_id"]) -> None: ...

global___Alexa_ASK_Skill = Alexa_ASK_Skill

@typing_extensions.final
class Alexa_ASK(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALEXA__A_S_K__SKILL_FIELD_NUMBER: builtins.int
    @property
    def alexa__a_s_k__skill(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Alexa_ASK_Skill]: ...
    def __init__(
        self,
        *,
        alexa__a_s_k__skill: collections.abc.Iterable[global___Alexa_ASK_Skill] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alexa__a_s_k__skill", b"alexa__a_s_k__skill"]) -> None: ...

global___Alexa_ASK = Alexa_ASK



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_config.proto\x12\x16oak9.tython.aws.config\x1a\x13shared/shared.proto\"\x88\x02\n\x18\x41ggregationAuthorization\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x61uthorized_account_id\x18\x02 \x01(\t\x12\x1d\n\x15\x61uthorized_aws_region\x18\x03 \x01(\t\x12H\n\x04tags\x18\x04 \x03(\x0b\x32:.oak9.tython.aws.config.AggregationAuthorization.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcc\x06\n\x06\x43onfig\x12S\n\x19\x61ggregation_authorization\x18\x01 \x03(\x0b\x32\x30.oak9.tython.aws.config.AggregationAuthorization\x12\x37\n\x0b\x63onfig_rule\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.config.ConfigRule\x12Q\n\x18\x63onfiguration_aggregator\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.config.ConfigurationAggregator\x12M\n\x16\x63onfiguration_recorder\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.config.ConfigurationRecorder\x12\x41\n\x10\x63onformance_pack\x18\x05 \x03(\x0b\x32\'.oak9.tython.aws.config.ConformancePack\x12\x41\n\x10\x64\x65livery_channel\x18\x06 \x03(\x0b\x32\'.oak9.tython.aws.config.DeliveryChannel\x12P\n\x18organization_config_rule\x18\x07 \x03(\x0b\x32..oak9.tython.aws.config.OrganizationConfigRule\x12Z\n\x1dorganization_conformance_pack\x18\x08 \x03(\x0b\x32\x33.oak9.tython.aws.config.OrganizationConformancePack\x12S\n\x19remediation_configuration\x18\t \x03(\x0b\x32\x30.oak9.tython.aws.config.RemediationConfiguration\x12\x88\x01\n5remediation_configuration_remediation_parameter_value\x18\n \x03(\x0b\x32I.oak9.tython.aws.config.RemediationConfigurationRemediationParameterValue\"\xb1\x01\n\x0f\x43onfigRuleScope\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x63ompliance_resource_id\x18\x02 \x01(\t\x12!\n\x19\x63ompliance_resource_types\x18\x03 \x03(\t\x12\x0f\n\x07tag_key\x18\x04 \x01(\t\x12\x11\n\ttag_value\x18\x05 \x01(\t\"\xa2\x01\n\x16\x43onfigRuleSourceDetail\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x65vent_source\x18\x02 \x01(\t\x12#\n\x1bmaximum_execution_frequency\x18\x03 \x01(\t\x12\x14\n\x0cmessage_type\x18\x04 \x01(\t\"\xbd\x01\n\x10\x43onfigRuleSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x46\n\x0esource_details\x18\x03 \x03(\x0b\x32..oak9.tython.aws.config.ConfigRuleSourceDetail\x12\x19\n\x11source_identifier\x18\x04 \x01(\t\"\x96\x03\n\nConfigRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x63onfig_rule_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12Q\n\x10input_parameters\x18\x04 \x03(\x0b\x32\x37.oak9.tython.aws.config.ConfigRule.InputParametersEntry\x12#\n\x1bmaximum_execution_frequency\x18\x05 \x01(\t\x12\x36\n\x05scope\x18\x06 \x01(\x0b\x32\'.oak9.tython.aws.config.ConfigRuleScope\x12\x38\n\x06source\x18\x07 \x01(\x0b\x32(.oak9.tython.aws.config.ConfigRuleSource\x1a\x36\n\x14InputParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xad\x01\n/ConfigurationAggregatorAccountAggregationSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61ll_aws_regions\x18\x02 \x01(\x08\x12\x13\n\x0b\x61ws_regions\x18\x03 \x03(\t\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x04 \x03(\t\"\xaf\x01\n4ConfigurationAggregatorOrganizationAggregationSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61ll_aws_regions\x18\x02 \x01(\x08\x12\x13\n\x0b\x61ws_regions\x18\x03 \x03(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"\xd4\x03\n\x17\x43onfigurationAggregator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12l\n\x1b\x61\x63\x63ount_aggregation_sources\x18\x02 \x03(\x0b\x32G.oak9.tython.aws.config.ConfigurationAggregatorAccountAggregationSource\x12%\n\x1d\x63onfiguration_aggregator_name\x18\x03 \x01(\t\x12u\n\x1forganization_aggregation_source\x18\x04 \x01(\x0b\x32L.oak9.tython.aws.config.ConfigurationAggregatorOrganizationAggregationSource\x12G\n\x04tags\x18\x05 \x03(\x0b\x32\x39.oak9.tython.aws.config.ConfigurationAggregator.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x01\n#ConfigurationRecorderRecordingGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rall_supported\x18\x02 \x01(\x08\x12%\n\x1dinclude_global_resource_types\x18\x03 \x01(\x08\x12\x16\n\x0eresource_types\x18\x04 \x03(\t\"\xc6\x01\n\x15\x43onfigurationRecorder\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12T\n\x0frecording_group\x18\x03 \x01(\x0b\x32;.oak9.tython.aws.config.ConfigurationRecorderRecordingGroup\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"\x98\x01\n,ConformancePackConformancePackInputParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eparameter_name\x18\x02 \x01(\t\x12\x17\n\x0fparameter_value\x18\x03 \x01(\t\"\xc6\x02\n\x0f\x43onformancePack\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63onformance_pack_name\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65livery_s3_bucket\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x65livery_s3_key_prefix\x18\x04 \x01(\t\x12\x15\n\rtemplate_body\x18\x05 \x01(\t\x12\x17\n\x0ftemplate_s3_uri\x18\x06 \x01(\t\x12o\n!conformance_pack_input_parameters\x18\x07 \x03(\x0b\x32\x44.oak9.tython.aws.config.ConformancePackConformancePackInputParameter\"\x86\x01\n/DeliveryChannelConfigSnapshotDeliveryProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x64\x65livery_frequency\x18\x02 \x01(\t\"\x94\x02\n\x0f\x44\x65liveryChannel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12t\n#config_snapshot_delivery_properties\x18\x02 \x01(\x0b\x32G.oak9.tython.aws.config.DeliveryChannelConfigSnapshotDeliveryProperties\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x16\n\x0es3_bucket_name\x18\x04 \x01(\t\x12\x15\n\rs3_key_prefix\x18\x05 \x01(\t\x12\x15\n\rsns_topic_arn\x18\x06 \x01(\t\"\xc6\x02\n5OrganizationConfigRuleOrganizationManagedRuleMetadata\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rtag_key_scope\x18\x02 \x01(\t\x12\x17\n\x0ftag_value_scope\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x19\n\x11resource_id_scope\x18\x05 \x01(\t\x12\x17\n\x0frule_identifier\x18\x06 \x01(\t\x12\x1c\n\x14resource_types_scope\x18\x07 \x03(\t\x12#\n\x1bmaximum_execution_frequency\x18\x08 \x01(\t\x12\x18\n\x10input_parameters\x18\t \x01(\t\"\xf9\x02\n4OrganizationConfigRuleOrganizationCustomRuleMetadata\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rtag_key_scope\x18\x02 \x01(\t\x12\x17\n\x0ftag_value_scope\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x19\n\x11resource_id_scope\x18\x05 \x01(\t\x12\x1b\n\x13lambda_function_arn\x18\x06 \x01(\t\x12.\n&organization_config_rule_trigger_types\x18\x07 \x03(\t\x12\x1c\n\x14resource_types_scope\x18\x08 \x03(\t\x12#\n\x1bmaximum_execution_frequency\x18\t \x01(\t\x12\x18\n\x10input_parameters\x18\n \x01(\t\"\x87\x03\n\x16OrganizationConfigRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12y\n\"organization_managed_rule_metadata\x18\x02 \x01(\x0b\x32M.oak9.tython.aws.config.OrganizationConfigRuleOrganizationManagedRuleMetadata\x12%\n\x1dorganization_config_rule_name\x18\x03 \x01(\t\x12w\n!organization_custom_rule_metadata\x18\x04 \x01(\x0b\x32L.oak9.tython.aws.config.OrganizationConfigRuleOrganizationCustomRuleMetadata\x12\x19\n\x11\x65xcluded_accounts\x18\x05 \x03(\t\"\xa4\x01\n8OrganizationConformancePackConformancePackInputParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eparameter_name\x18\x02 \x01(\t\x12\x17\n\x0fparameter_value\x18\x03 \x01(\t\"\x86\x03\n\x1bOrganizationConformancePack\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12*\n\"organization_conformance_pack_name\x18\x02 \x01(\t\x12\x17\n\x0ftemplate_s3_uri\x18\x03 \x01(\t\x12\x15\n\rtemplate_body\x18\x04 \x01(\t\x12\x1a\n\x12\x64\x65livery_s3_bucket\x18\x05 \x01(\t\x12\x1e\n\x16\x64\x65livery_s3_key_prefix\x18\x06 \x01(\t\x12{\n!conformance_pack_input_parameters\x18\x07 \x03(\x0b\x32P.oak9.tython.aws.config.OrganizationConformancePackConformancePackInputParameter\x12\x19\n\x11\x65xcluded_accounts\x18\x08 \x03(\t\"\xa6\x01\n#RemediationConfigurationSsmControls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x65rror_percentage\x18\x02 \x01(\x05\x12,\n$concurrent_execution_rate_percentage\x18\x03 \x01(\x05\"\xb7\x01\n)RemediationConfigurationExecutionControls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\x0cssm_controls\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.config.RemediationConfigurationSsmControls\"\x82\x04\n\x18RemediationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0etarget_version\x18\x02 \x01(\t\x12]\n\x12\x65xecution_controls\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.config.RemediationConfigurationExecutionControls\x12T\n\nparameters\x18\x04 \x03(\x0b\x32@.oak9.tython.aws.config.RemediationConfiguration.ParametersEntry\x12\x13\n\x0btarget_type\x18\x05 \x01(\t\x12\x18\n\x10\x63onfig_rule_name\x18\x06 \x01(\t\x12\x15\n\rresource_type\x18\x07 \x01(\t\x12\x1d\n\x15retry_attempt_seconds\x18\x08 \x01(\x05\x12\"\n\x1amaximum_automatic_attempts\x18\t \x01(\x05\x12\x11\n\ttarget_id\x18\n \x01(\t\x12\x11\n\tautomatic\x18\x0b \x01(\x08\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n%RemediationConfigurationResourceValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\"n\n#RemediationConfigurationStaticValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"\x96\x02\n1RemediationConfigurationRemediationParameterValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x0eresource_value\x18\x02 \x01(\x0b\x32=.oak9.tython.aws.config.RemediationConfigurationResourceValue\x12Q\n\x0cstatic_value\x18\x03 \x01(\x0b\x32;.oak9.tython.aws.config.RemediationConfigurationStaticValueb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AGGREGATIONAUTHORIZATION_TAGSENTRY._options = None
  _AGGREGATIONAUTHORIZATION_TAGSENTRY._serialized_options = b'8\001'
  _CONFIGRULE_INPUTPARAMETERSENTRY._options = None
  _CONFIGRULE_INPUTPARAMETERSENTRY._serialized_options = b'8\001'
  _CONFIGURATIONAGGREGATOR_TAGSENTRY._options = None
  _CONFIGURATIONAGGREGATOR_TAGSENTRY._serialized_options = b'8\001'
  _REMEDIATIONCONFIGURATION_PARAMETERSENTRY._options = None
  _REMEDIATIONCONFIGURATION_PARAMETERSENTRY._serialized_options = b'8\001'
  _AGGREGATIONAUTHORIZATION._serialized_start=70
  _AGGREGATIONAUTHORIZATION._serialized_end=334
  _AGGREGATIONAUTHORIZATION_TAGSENTRY._serialized_start=291
  _AGGREGATIONAUTHORIZATION_TAGSENTRY._serialized_end=334
  _CONFIG._serialized_start=337
  _CONFIG._serialized_end=1181
  _CONFIGRULESCOPE._serialized_start=1184
  _CONFIGRULESCOPE._serialized_end=1361
  _CONFIGRULESOURCEDETAIL._serialized_start=1364
  _CONFIGRULESOURCEDETAIL._serialized_end=1526
  _CONFIGRULESOURCE._serialized_start=1529
  _CONFIGRULESOURCE._serialized_end=1718
  _CONFIGRULE._serialized_start=1721
  _CONFIGRULE._serialized_end=2127
  _CONFIGRULE_INPUTPARAMETERSENTRY._serialized_start=2073
  _CONFIGRULE_INPUTPARAMETERSENTRY._serialized_end=2127
  _CONFIGURATIONAGGREGATORACCOUNTAGGREGATIONSOURCE._serialized_start=2130
  _CONFIGURATIONAGGREGATORACCOUNTAGGREGATIONSOURCE._serialized_end=2303
  _CONFIGURATIONAGGREGATORORGANIZATIONAGGREGATIONSOURCE._serialized_start=2306
  _CONFIGURATIONAGGREGATORORGANIZATIONAGGREGATIONSOURCE._serialized_end=2481
  _CONFIGURATIONAGGREGATOR._serialized_start=2484
  _CONFIGURATIONAGGREGATOR._serialized_end=2952
  _CONFIGURATIONAGGREGATOR_TAGSENTRY._serialized_start=291
  _CONFIGURATIONAGGREGATOR_TAGSENTRY._serialized_end=334
  _CONFIGURATIONRECORDERRECORDINGGROUP._serialized_start=2955
  _CONFIGURATIONRECORDERRECORDINGGROUP._serialized_end=3135
  _CONFIGURATIONRECORDER._serialized_start=3138
  _CONFIGURATIONRECORDER._serialized_end=3336
  _CONFORMANCEPACKCONFORMANCEPACKINPUTPARAMETER._serialized_start=3339
  _CONFORMANCEPACKCONFORMANCEPACKINPUTPARAMETER._serialized_end=3491
  _CONFORMANCEPACK._serialized_start=3494
  _CONFORMANCEPACK._serialized_end=3820
  _DELIVERYCHANNELCONFIGSNAPSHOTDELIVERYPROPERTIES._serialized_start=3823
  _DELIVERYCHANNELCONFIGSNAPSHOTDELIVERYPROPERTIES._serialized_end=3957
  _DELIVERYCHANNEL._serialized_start=3960
  _DELIVERYCHANNEL._serialized_end=4236
  _ORGANIZATIONCONFIGRULEORGANIZATIONMANAGEDRULEMETADATA._serialized_start=4239
  _ORGANIZATIONCONFIGRULEORGANIZATIONMANAGEDRULEMETADATA._serialized_end=4565
  _ORGANIZATIONCONFIGRULEORGANIZATIONCUSTOMRULEMETADATA._serialized_start=4568
  _ORGANIZATIONCONFIGRULEORGANIZATIONCUSTOMRULEMETADATA._serialized_end=4945
  _ORGANIZATIONCONFIGRULE._serialized_start=4948
  _ORGANIZATIONCONFIGRULE._serialized_end=5339
  _ORGANIZATIONCONFORMANCEPACKCONFORMANCEPACKINPUTPARAMETER._serialized_start=5342
  _ORGANIZATIONCONFORMANCEPACKCONFORMANCEPACKINPUTPARAMETER._serialized_end=5506
  _ORGANIZATIONCONFORMANCEPACK._serialized_start=5509
  _ORGANIZATIONCONFORMANCEPACK._serialized_end=5899
  _REMEDIATIONCONFIGURATIONSSMCONTROLS._serialized_start=5902
  _REMEDIATIONCONFIGURATIONSSMCONTROLS._serialized_end=6068
  _REMEDIATIONCONFIGURATIONEXECUTIONCONTROLS._serialized_start=6071
  _REMEDIATIONCONFIGURATIONEXECUTIONCONTROLS._serialized_end=6254
  _REMEDIATIONCONFIGURATION._serialized_start=6257
  _REMEDIATIONCONFIGURATION._serialized_end=6771
  _REMEDIATIONCONFIGURATION_PARAMETERSENTRY._serialized_start=6722
  _REMEDIATIONCONFIGURATION_PARAMETERSENTRY._serialized_end=6771
  _REMEDIATIONCONFIGURATIONRESOURCEVALUE._serialized_start=6773
  _REMEDIATIONCONFIGURATIONRESOURCEVALUE._serialized_end=6884
  _REMEDIATIONCONFIGURATIONSTATICVALUE._serialized_start=6886
  _REMEDIATIONCONFIGURATIONSTATICVALUE._serialized_end=6996
  _REMEDIATIONCONFIGURATIONREMEDIATIONPARAMETERVALUE._serialized_start=6999
  _REMEDIATIONCONFIGURATIONREMEDIATIONPARAMETERVALUE._serialized_end=7277
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class APIGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PREFERRED_VERSION_FIELD_NUMBER: builtins.int
    SERVER_ADDRESS_BY_CLIENT_CIDRS_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    name: builtins.str
    @property
    def preferred_version(self) -> global___GroupVersionForDiscovery: ...
    @property
    def server_address_by_client_cidrs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServerAddressByClientCIDR]: ...
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GroupVersionForDiscovery]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        preferred_version: global___GroupVersionForDiscovery | None = ...,
        server_address_by_client_cidrs: collections.abc.Iterable[global___ServerAddressByClientCIDR] | None = ...,
        versions: collections.abc.Iterable[global___GroupVersionForDiscovery] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preferred_version", b"preferred_version", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "name", b"name", "preferred_version", b"preferred_version", "resource_info", b"resource_info", "server_address_by_client_cidrs", b"server_address_by_client_cidrs", "versions", b"versions"]) -> None: ...

global___APIGroup = APIGroup

@typing_extensions.final
class APIGroupList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___APIGroup]: ...
    kind: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        groups: collections.abc.Iterable[global___APIGroup] | None = ...,
        kind: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "groups", b"groups", "kind", b"kind", "resource_info", b"resource_info"]) -> None: ...

global___APIGroupList = APIGroupList

@typing_extensions.final
class APIResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORIES_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACED_FIELD_NUMBER: builtins.int
    SHORT_NAMES_FIELD_NUMBER: builtins.int
    SINGULAR_NAME_FIELD_NUMBER: builtins.int
    STORAGE_VERSION_HASH_FIELD_NUMBER: builtins.int
    VERBS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def categories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    group: builtins.str
    kind: builtins.str
    name: builtins.str
    namespaced: builtins.bool
    @property
    def short_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    singular_name: builtins.str
    storage_version_hash: builtins.str
    @property
    def verbs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    version: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        categories: collections.abc.Iterable[builtins.str] | None = ...,
        group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        namespaced: builtins.bool = ...,
        short_names: collections.abc.Iterable[builtins.str] | None = ...,
        singular_name: builtins.str = ...,
        storage_version_hash: builtins.str = ...,
        verbs: collections.abc.Iterable[builtins.str] | None = ...,
        version: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["categories", b"categories", "group", b"group", "kind", b"kind", "name", b"name", "namespaced", b"namespaced", "resource_info", b"resource_info", "short_names", b"short_names", "singular_name", b"singular_name", "storage_version_hash", b"storage_version_hash", "verbs", b"verbs", "version", b"version"]) -> None: ...

global___APIResource = APIResource

@typing_extensions.final
class APIResourceList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    GROUP_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    group_version: builtins.str
    kind: builtins.str
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___APIResource]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        group_version: builtins.str = ...,
        kind: builtins.str = ...,
        resources: collections.abc.Iterable[global___APIResource] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "group_version", b"group_version", "kind", b"kind", "resource_info", b"resource_info", "resources", b"resources"]) -> None: ...

global___APIResourceList = APIResourceList

@typing_extensions.final
class APIVersions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    SERVER_ADDRESS_BY_CLIENT_CIDRS_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def server_address_by_client_cidrs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServerAddressByClientCIDR]: ...
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        server_address_by_client_cidrs: collections.abc.Iterable[global___ServerAddressByClientCIDR] | None = ...,
        versions: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "resource_info", b"resource_info", "server_address_by_client_cidrs", b"server_address_by_client_cidrs", "versions", b"versions"]) -> None: ...

global___APIVersions = APIVersions

@typing_extensions.final
class Condition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> global___Time: ...
    message: builtins.str
    observed_generation: builtins.int
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: global___Time | None = ...,
        message: builtins.str = ...,
        observed_generation: builtins.int = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "observed_generation", b"observed_generation", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___Condition = Condition

@typing_extensions.final
class DeleteOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    DRY_RUN_FIELD_NUMBER: builtins.int
    GRACE_PERIOD_SECONDS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    ORPHAN_DEPENDENTS_FIELD_NUMBER: builtins.int
    PRECONDITIONS_FIELD_NUMBER: builtins.int
    PROPAGATION_POLICY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def dry_run(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    grace_period_seconds: builtins.int
    kind: builtins.str
    orphan_dependents: builtins.bool
    @property
    def preconditions(self) -> global___Preconditions: ...
    propagation_policy: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        dry_run: collections.abc.Iterable[builtins.str] | None = ...,
        grace_period_seconds: builtins.int = ...,
        kind: builtins.str = ...,
        orphan_dependents: builtins.bool = ...,
        preconditions: global___Preconditions | None = ...,
        propagation_policy: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preconditions", b"preconditions", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "dry_run", b"dry_run", "grace_period_seconds", b"grace_period_seconds", "kind", b"kind", "orphan_dependents", b"orphan_dependents", "preconditions", b"preconditions", "propagation_policy", b"propagation_policy", "resource_info", b"resource_info"]) -> None: ...

global___DeleteOptions = DeleteOptions

@typing_extensions.final
class FieldsV1(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___FieldsV1 = FieldsV1

@typing_extensions.final
class GroupVersionForDiscovery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_VERSION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    group_version: builtins.str
    version: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        group_version: builtins.str = ...,
        version: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_version", b"group_version", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___GroupVersionForDiscovery = GroupVersionForDiscovery

@typing_extensions.final
class LabelSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MatchLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    MATCH_EXPRESSIONS_FIELD_NUMBER: builtins.int
    MATCH_LABELS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def match_expressions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LabelSelectorRequirement]: ...
    @property
    def match_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        match_expressions: collections.abc.Iterable[global___LabelSelectorRequirement] | None = ...,
        match_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_expressions", b"match_expressions", "match_labels", b"match_labels", "resource_info", b"resource_info"]) -> None: ...

global___LabelSelector = LabelSelector

@typing_extensions.final
class LabelSelectorRequirement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    key: builtins.str
    operator: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        operator: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "operator", b"operator", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___LabelSelectorRequirement = LabelSelectorRequirement

@typing_extensions.final
class ListMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTINUE_FIELD_NUMBER: builtins.int
    REMAINING_ITEM_COUNT_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    remaining_item_count: builtins.int
    resource_version: builtins.str
    self_link: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        remaining_item_count: builtins.int = ...,
        resource_version: builtins.str = ...,
        self_link: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["continue", b"continue", "remaining_item_count", b"remaining_item_count", "resource_info", b"resource_info", "resource_version", b"resource_version", "self_link", b"self_link"]) -> None: ...

global___ListMeta = ListMeta

@typing_extensions.final
class ManagedFieldsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    FIELDS_TYPE_FIELD_NUMBER: builtins.int
    FIELDS_V1_FIELD_NUMBER: builtins.int
    MANAGER_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    SUBRESOURCE_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    fields_type: builtins.str
    @property
    def fields_v1(self) -> global___FieldsV1: ...
    manager: builtins.str
    operation: builtins.str
    subresource: builtins.str
    @property
    def time(self) -> global___Time: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        fields_type: builtins.str = ...,
        fields_v1: global___FieldsV1 | None = ...,
        manager: builtins.str = ...,
        operation: builtins.str = ...,
        subresource: builtins.str = ...,
        time: global___Time | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fields_v1", b"fields_v1", "resource_info", b"resource_info", "time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "fields_type", b"fields_type", "fields_v1", b"fields_v1", "manager", b"manager", "operation", b"operation", "resource_info", b"resource_info", "subresource", b"subresource", "time", b"time"]) -> None: ...

global___ManagedFieldsEntry = ManagedFieldsEntry

@typing_extensions.final
class MicroTime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___MicroTime = MicroTime

@typing_extensions.final
class ObjectMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DELETION_GRACE_PERIOD_SECONDS_FIELD_NUMBER: builtins.int
    DELETION_TIMESTAMP_FIELD_NUMBER: builtins.int
    FINALIZERS_FIELD_NUMBER: builtins.int
    GENERATE_NAME_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MANAGED_FIELDS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    OWNER_REFERENCES_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def creation_timestamp(self) -> global___Time: ...
    deletion_grace_period_seconds: builtins.int
    @property
    def deletion_timestamp(self) -> global___Time: ...
    @property
    def finalizers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    generate_name: builtins.str
    generation: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def managed_fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedFieldsEntry]: ...
    name: builtins.str
    namespace: builtins.str
    @property
    def owner_references(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OwnerReference]: ...
    resource_version: builtins.str
    self_link: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        creation_timestamp: global___Time | None = ...,
        deletion_grace_period_seconds: builtins.int = ...,
        deletion_timestamp: global___Time | None = ...,
        finalizers: collections.abc.Iterable[builtins.str] | None = ...,
        generate_name: builtins.str = ...,
        generation: builtins.int = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_fields: collections.abc.Iterable[global___ManagedFieldsEntry] | None = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        owner_references: collections.abc.Iterable[global___OwnerReference] | None = ...,
        resource_version: builtins.str = ...,
        self_link: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "deletion_timestamp", b"deletion_timestamp", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "creation_timestamp", b"creation_timestamp", "deletion_grace_period_seconds", b"deletion_grace_period_seconds", "deletion_timestamp", b"deletion_timestamp", "finalizers", b"finalizers", "generate_name", b"generate_name", "generation", b"generation", "labels", b"labels", "managed_fields", b"managed_fields", "name", b"name", "namespace", b"namespace", "owner_references", b"owner_references", "resource_info", b"resource_info", "resource_version", b"resource_version", "self_link", b"self_link", "uid", b"uid"]) -> None: ...

global___ObjectMeta = ObjectMeta

@typing_extensions.final
class OwnerReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    BLOCK_OWNER_DELETION_FIELD_NUMBER: builtins.int
    CONTROLLER_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    block_owner_deletion: builtins.bool
    controller: builtins.bool
    kind: builtins.str
    name: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        block_owner_deletion: builtins.bool = ...,
        controller: builtins.bool = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "block_owner_deletion", b"block_owner_deletion", "controller", b"controller", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "uid", b"uid"]) -> None: ...

global___OwnerReference = OwnerReference

@typing_extensions.final
class Patch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___Patch = Patch

@typing_extensions.final
class Preconditions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    resource_version: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_version: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "resource_version", b"resource_version", "uid", b"uid"]) -> None: ...

global___Preconditions = Preconditions

@typing_extensions.final
class ServerAddressByClientCIDR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_CIDR_FIELD_NUMBER: builtins.int
    SERVER_ADDRESS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_cidr: builtins.str
    server_address: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_cidr: builtins.str = ...,
        server_address: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_cidr", b"client_cidr", "resource_info", b"resource_info", "server_address", b"server_address"]) -> None: ...

global___ServerAddressByClientCIDR = ServerAddressByClientCIDR

@typing_extensions.final
class Status(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    code: builtins.int
    @property
    def details(self) -> global___StatusDetails: ...
    kind: builtins.str
    message: builtins.str
    @property
    def metadata(self) -> global___ListMeta: ...
    reason: builtins.str
    status: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        code: builtins.int = ...,
        details: global___StatusDetails | None = ...,
        kind: builtins.str = ...,
        message: builtins.str = ...,
        metadata: global___ListMeta | None = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["details", b"details", "metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "code", b"code", "details", b"details", "kind", b"kind", "message", b"message", "metadata", b"metadata", "reason", b"reason", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___Status = Status

@typing_extensions.final
class StatusCause(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    field: builtins.str
    message: builtins.str
    reason: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        field: builtins.str = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field", b"field", "message", b"message", "reason", b"reason", "resource_info", b"resource_info"]) -> None: ...

global___StatusCause = StatusCause

@typing_extensions.final
class StatusDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAUSES_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETRY_AFTER_SECONDS_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def causes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StatusCause]: ...
    group: builtins.str
    kind: builtins.str
    name: builtins.str
    retry_after_seconds: builtins.int
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        causes: collections.abc.Iterable[global___StatusCause] | None = ...,
        group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        retry_after_seconds: builtins.int = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["causes", b"causes", "group", b"group", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "retry_after_seconds", b"retry_after_seconds", "uid", b"uid"]) -> None: ...

global___StatusDetails = StatusDetails

@typing_extensions.final
class Time(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___Time = Time

@typing_extensions.final
class WatchEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def object(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2.RawExtension: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        object: kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2.RawExtension | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___WatchEvent = WatchEvent



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Sql_Databases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVERS_DATABASES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_BACKUP_LONG_TERM_RETENTION_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_BACKUP_SHORT_TERM_RETENTION_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_EXTENDED_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_EXTENSIONS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_SECURITY_ALERT_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_SYNC_GROUPS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_SYNC_GROUPS_SYNC_MEMBERS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_TRANSPARENT_DATA_ENCRYPTION_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_VULNERABILITY_ASSESSMENTS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_VULNERABILITY_ASSESSMENTS_RULES_BASELINES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_CONNECTION_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_DATA_MASKING_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_GEO_BACKUP_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def servers_databases(self) -> global___ServersDatabases: ...
    @property
    def servers_databases_auditing_settings(self) -> global___ServersDatabasesAuditingSettings: ...
    @property
    def servers_databases_backup_long_term_retention_policies(self) -> global___ServersDatabasesBackupLongTermRetentionPolicies: ...
    @property
    def servers_databases_backup_short_term_retention_policies(self) -> global___ServersDatabasesBackupShortTermRetentionPolicies: ...
    @property
    def servers_databases_extended_auditing_settings(self) -> global___ServersDatabasesExtendedAuditingSettings: ...
    @property
    def servers_databases_extensions(self) -> global___ServersDatabasesExtensions: ...
    @property
    def servers_databases_security_alert_policies(self) -> global___ServersDatabasesSecurityAlertPolicies: ...
    @property
    def servers_databases_sync_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesSyncGroups]: ...
    @property
    def servers_databases_sync_groups_sync_members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesSyncGroupsSyncMembers]: ...
    @property
    def servers_databases_transparent_data_encryption(self) -> global___ServersDatabasesTransparentDataEncryption: ...
    @property
    def servers_databases_vulnerability_assessments(self) -> global___ServersDatabasesVulnerabilityAssessments: ...
    @property
    def servers_databases_vulnerability_assessments_rules_baselines(self) -> global___ServersDatabasesVulnerabilityAssessmentsRulesBaselines: ...
    @property
    def servers_databases_connection_policies(self) -> global___ServersDatabasesConnectionPolicies: ...
    @property
    def servers_databases_data_masking_policies(self) -> global___ServersDatabasesDataMaskingPolicies: ...
    @property
    def servers_databases_geo_backup_policies(self) -> global___ServersDatabasesGeoBackupPolicies: ...
    def __init__(
        self,
        *,
        servers_databases: global___ServersDatabases | None = ...,
        servers_databases_auditing_settings: global___ServersDatabasesAuditingSettings | None = ...,
        servers_databases_backup_long_term_retention_policies: global___ServersDatabasesBackupLongTermRetentionPolicies | None = ...,
        servers_databases_backup_short_term_retention_policies: global___ServersDatabasesBackupShortTermRetentionPolicies | None = ...,
        servers_databases_extended_auditing_settings: global___ServersDatabasesExtendedAuditingSettings | None = ...,
        servers_databases_extensions: global___ServersDatabasesExtensions | None = ...,
        servers_databases_security_alert_policies: global___ServersDatabasesSecurityAlertPolicies | None = ...,
        servers_databases_sync_groups: collections.abc.Iterable[global___ServersDatabasesSyncGroups] | None = ...,
        servers_databases_sync_groups_sync_members: collections.abc.Iterable[global___ServersDatabasesSyncGroupsSyncMembers] | None = ...,
        servers_databases_transparent_data_encryption: global___ServersDatabasesTransparentDataEncryption | None = ...,
        servers_databases_vulnerability_assessments: global___ServersDatabasesVulnerabilityAssessments | None = ...,
        servers_databases_vulnerability_assessments_rules_baselines: global___ServersDatabasesVulnerabilityAssessmentsRulesBaselines | None = ...,
        servers_databases_connection_policies: global___ServersDatabasesConnectionPolicies | None = ...,
        servers_databases_data_masking_policies: global___ServersDatabasesDataMaskingPolicies | None = ...,
        servers_databases_geo_backup_policies: global___ServersDatabasesGeoBackupPolicies | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["servers_databases", b"servers_databases", "servers_databases_auditing_settings", b"servers_databases_auditing_settings", "servers_databases_backup_long_term_retention_policies", b"servers_databases_backup_long_term_retention_policies", "servers_databases_backup_short_term_retention_policies", b"servers_databases_backup_short_term_retention_policies", "servers_databases_connection_policies", b"servers_databases_connection_policies", "servers_databases_data_masking_policies", b"servers_databases_data_masking_policies", "servers_databases_extended_auditing_settings", b"servers_databases_extended_auditing_settings", "servers_databases_extensions", b"servers_databases_extensions", "servers_databases_geo_backup_policies", b"servers_databases_geo_backup_policies", "servers_databases_security_alert_policies", b"servers_databases_security_alert_policies", "servers_databases_transparent_data_encryption", b"servers_databases_transparent_data_encryption", "servers_databases_vulnerability_assessments", b"servers_databases_vulnerability_assessments", "servers_databases_vulnerability_assessments_rules_baselines", b"servers_databases_vulnerability_assessments_rules_baselines"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["servers_databases", b"servers_databases", "servers_databases_auditing_settings", b"servers_databases_auditing_settings", "servers_databases_backup_long_term_retention_policies", b"servers_databases_backup_long_term_retention_policies", "servers_databases_backup_short_term_retention_policies", b"servers_databases_backup_short_term_retention_policies", "servers_databases_connection_policies", b"servers_databases_connection_policies", "servers_databases_data_masking_policies", b"servers_databases_data_masking_policies", "servers_databases_extended_auditing_settings", b"servers_databases_extended_auditing_settings", "servers_databases_extensions", b"servers_databases_extensions", "servers_databases_geo_backup_policies", b"servers_databases_geo_backup_policies", "servers_databases_security_alert_policies", b"servers_databases_security_alert_policies", "servers_databases_sync_groups", b"servers_databases_sync_groups", "servers_databases_sync_groups_sync_members", b"servers_databases_sync_groups_sync_members", "servers_databases_transparent_data_encryption", b"servers_databases_transparent_data_encryption", "servers_databases_vulnerability_assessments", b"servers_databases_vulnerability_assessments", "servers_databases_vulnerability_assessments_rules_baselines", b"servers_databases_vulnerability_assessments_rules_baselines"]) -> None: ...

global___Microsoft_Sql_Databases = Microsoft_Sql_Databases

@typing_extensions.final
class ServersDatabasesGeoBackupPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    state: builtins.str
    storage_type: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        state: builtins.str = ...,
        storage_type: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "kind", b"kind", "location", b"location", "name", b"name", "resource_info", b"resource_info", "state", b"state", "storage_type", b"storage_type", "type", b"type"]) -> None: ...

global___ServersDatabasesGeoBackupPolicies = ServersDatabasesGeoBackupPolicies

@typing_extensions.final
class ServersDatabasesDataMaskingPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    DATA_MASKING_STATE_FIELD_NUMBER: builtins.int
    APPLICATION_PRINCIPALS_FIELD_NUMBER: builtins.int
    EXEMPT_PRINCIPALS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    name: builtins.str
    kind: builtins.str
    data_masking_state: builtins.str
    application_principals: builtins.str
    exempt_principals: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        kind: builtins.str = ...,
        data_masking_state: builtins.str = ...,
        application_principals: builtins.str = ...,
        exempt_principals: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_principals", b"application_principals", "data_masking_state", b"data_masking_state", "exempt_principals", b"exempt_principals", "id", b"id", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___ServersDatabasesDataMaskingPolicies = ServersDatabasesDataMaskingPolicies

@typing_extensions.final
class ServersDatabasesConnectionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONNECTION_TYPE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    name: builtins.str
    connection_type: builtins.str
    kind: builtins.str
    location: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        connection_type: builtins.str = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_type", b"connection_type", "id", b"id", "kind", b"kind", "location", b"location", "name", b"name", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___ServersDatabasesConnectionPolicies = ServersDatabasesConnectionPolicies

@typing_extensions.final
class ServersDatabasesWorkloadGroupsWorkloadClassifiers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    IMPORTANCE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    MEMBER_NAME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    context: builtins.str
    end_time: builtins.str
    importance: builtins.str
    label: builtins.str
    member_name: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        context: builtins.str = ...,
        end_time: builtins.str = ...,
        importance: builtins.str = ...,
        label: builtins.str = ...,
        member_name: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "end_time", b"end_time", "importance", b"importance", "label", b"label", "member_name", b"member_name", "name", b"name", "resource_info", b"resource_info", "start_time", b"start_time"]) -> None: ...

global___ServersDatabasesWorkloadGroupsWorkloadClassifiers = ServersDatabasesWorkloadGroupsWorkloadClassifiers

@typing_extensions.final
class ServersDatabasesWorkloadGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMPORTANCE_FIELD_NUMBER: builtins.int
    MAX_RESOURCE_PERCENT_FIELD_NUMBER: builtins.int
    MAX_RESOURCE_PERCENT_PER_REQUEST_FIELD_NUMBER: builtins.int
    MIN_RESOURCE_PERCENT_FIELD_NUMBER: builtins.int
    MIN_RESOURCE_PERCENT_PER_REQUEST_FIELD_NUMBER: builtins.int
    QUERY_EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_WORKLOAD_GROUPS_WORKLOAD_CLASSIFIERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    importance: builtins.str
    max_resource_percent: builtins.int
    max_resource_percent_per_request: builtins.float
    min_resource_percent: builtins.int
    min_resource_percent_per_request: builtins.float
    query_execution_timeout: builtins.int
    @property
    def servers_databases_workload_groups_workload_classifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesWorkloadGroupsWorkloadClassifiers]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        importance: builtins.str = ...,
        max_resource_percent: builtins.int = ...,
        max_resource_percent_per_request: builtins.float = ...,
        min_resource_percent: builtins.int = ...,
        min_resource_percent_per_request: builtins.float = ...,
        query_execution_timeout: builtins.int = ...,
        servers_databases_workload_groups_workload_classifiers: collections.abc.Iterable[global___ServersDatabasesWorkloadGroupsWorkloadClassifiers] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["importance", b"importance", "max_resource_percent", b"max_resource_percent", "max_resource_percent_per_request", b"max_resource_percent_per_request", "min_resource_percent", b"min_resource_percent", "min_resource_percent_per_request", b"min_resource_percent_per_request", "name", b"name", "query_execution_timeout", b"query_execution_timeout", "resource_info", b"resource_info", "servers_databases_workload_groups_workload_classifiers", b"servers_databases_workload_groups_workload_classifiers"]) -> None: ...

global___ServersDatabasesWorkloadGroups = ServersDatabasesWorkloadGroups

@typing_extensions.final
class ServersDatabasesVulnerabilityAssessmentsRulesBaselines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASELINE_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def baseline_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseVulnerabilityAssessmentRuleBaselineItem]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        baseline_results: collections.abc.Iterable[global___DatabaseVulnerabilityAssessmentRuleBaselineItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["baseline_results", b"baseline_results", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersDatabasesVulnerabilityAssessmentsRulesBaselines = ServersDatabasesVulnerabilityAssessmentsRulesBaselines

@typing_extensions.final
class DatabaseVulnerabilityAssessmentRuleBaselineItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        result: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___DatabaseVulnerabilityAssessmentRuleBaselineItem = DatabaseVulnerabilityAssessmentRuleBaselineItem

@typing_extensions.final
class ServersDatabasesVulnerabilityAssessments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RECURRING_SCANS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_PATH_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_KEY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EMAILS_FIELD_NUMBER: builtins.int
    EMAIL_SUBSCRIPTION_ADMINS_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def recurring_scans(self) -> global___VulnerabilityAssessmentRecurringScansProperties: ...
    storage_account_access_key: builtins.str
    storage_container_path: builtins.str
    storage_container_sas_key: builtins.str
    id: builtins.str
    type: builtins.str
    emails: builtins.str
    email_subscription_admins: builtins.str
    is_enabled: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        recurring_scans: global___VulnerabilityAssessmentRecurringScansProperties | None = ...,
        storage_account_access_key: builtins.str = ...,
        storage_container_path: builtins.str = ...,
        storage_container_sas_key: builtins.str = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
        emails: builtins.str = ...,
        email_subscription_admins: builtins.str = ...,
        is_enabled: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recurring_scans", b"recurring_scans", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["email_subscription_admins", b"email_subscription_admins", "emails", b"emails", "id", b"id", "is_enabled", b"is_enabled", "name", b"name", "recurring_scans", b"recurring_scans", "resource_info", b"resource_info", "storage_account_access_key", b"storage_account_access_key", "storage_container_path", b"storage_container_path", "storage_container_sas_key", b"storage_container_sas_key", "type", b"type"]) -> None: ...

global___ServersDatabasesVulnerabilityAssessments = ServersDatabasesVulnerabilityAssessments

@typing_extensions.final
class VulnerabilityAssessmentRecurringScansProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAILS_FIELD_NUMBER: builtins.int
    EMAIL_SUBSCRIPTION_ADMINS_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_subscription_admins: builtins.bool
    is_enabled: builtins.bool
    def __init__(
        self,
        *,
        emails: collections.abc.Iterable[builtins.str] | None = ...,
        email_subscription_admins: builtins.bool = ...,
        is_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email_subscription_admins", b"email_subscription_admins", "emails", b"emails", "is_enabled", b"is_enabled"]) -> None: ...

global___VulnerabilityAssessmentRecurringScansProperties = VulnerabilityAssessmentRecurringScansProperties

@typing_extensions.final
class ServersDatabasesTransparentDataEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    state: builtins.str
    id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        state: builtins.str = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "resource_info", b"resource_info", "state", b"state", "type", b"type"]) -> None: ...

global___ServersDatabasesTransparentDataEncryption = ServersDatabasesTransparentDataEncryption

@typing_extensions.final
class ServersDatabasesSyncGroupsSyncMembers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    DATABASE_TYPE_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    SQL_SERVER_DATABASE_ID_FIELD_NUMBER: builtins.int
    SYNC_AGENT_ID_FIELD_NUMBER: builtins.int
    SYNC_DIRECTION_FIELD_NUMBER: builtins.int
    SYNC_MEMBER_AZURE_DATABASE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    USE_PRIVATE_LINK_CONNECTION_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    database_name: builtins.str
    database_type: builtins.str
    password: builtins.str
    server_name: builtins.str
    sql_server_database_id: builtins.str
    sync_agent_id: builtins.str
    sync_direction: builtins.str
    sync_member_azure_database_resource_id: builtins.str
    use_private_link_connection: builtins.bool
    user_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        database_name: builtins.str = ...,
        database_type: builtins.str = ...,
        password: builtins.str = ...,
        server_name: builtins.str = ...,
        sql_server_database_id: builtins.str = ...,
        sync_agent_id: builtins.str = ...,
        sync_direction: builtins.str = ...,
        sync_member_azure_database_resource_id: builtins.str = ...,
        use_private_link_connection: builtins.bool = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name", "database_type", b"database_type", "name", b"name", "password", b"password", "resource_info", b"resource_info", "server_name", b"server_name", "sql_server_database_id", b"sql_server_database_id", "sync_agent_id", b"sync_agent_id", "sync_direction", b"sync_direction", "sync_member_azure_database_resource_id", b"sync_member_azure_database_resource_id", "use_private_link_connection", b"use_private_link_connection", "user_name", b"user_name"]) -> None: ...

global___ServersDatabasesSyncGroupsSyncMembers = ServersDatabasesSyncGroupsSyncMembers

@typing_extensions.final
class ServersDatabasesSyncGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFLICT_LOGGING_RETENTION_IN_DAYS_FIELD_NUMBER: builtins.int
    CONFLICT_RESOLUTION_POLICY_FIELD_NUMBER: builtins.int
    ENABLE_CONFLICT_LOGGING_FIELD_NUMBER: builtins.int
    HUB_DATABASE_PASSWORD_FIELD_NUMBER: builtins.int
    HUB_DATABASE_USER_NAME_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SYNC_DATABASE_ID_FIELD_NUMBER: builtins.int
    USE_PRIVATE_LINK_CONNECTION_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    conflict_logging_retention_in_days: builtins.int
    conflict_resolution_policy: builtins.str
    enable_conflict_logging: builtins.bool
    hub_database_password: builtins.str
    hub_database_user_name: builtins.str
    interval: builtins.int
    @property
    def schema(self) -> global___SyncGroupSchema: ...
    sync_database_id: builtins.str
    use_private_link_connection: builtins.bool
    @property
    def sku(self) -> global___Sku: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        conflict_logging_retention_in_days: builtins.int = ...,
        conflict_resolution_policy: builtins.str = ...,
        enable_conflict_logging: builtins.bool = ...,
        hub_database_password: builtins.str = ...,
        hub_database_user_name: builtins.str = ...,
        interval: builtins.int = ...,
        schema: global___SyncGroupSchema | None = ...,
        sync_database_id: builtins.str = ...,
        use_private_link_connection: builtins.bool = ...,
        sku: global___Sku | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "schema", b"schema", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conflict_logging_retention_in_days", b"conflict_logging_retention_in_days", "conflict_resolution_policy", b"conflict_resolution_policy", "enable_conflict_logging", b"enable_conflict_logging", "hub_database_password", b"hub_database_password", "hub_database_user_name", b"hub_database_user_name", "interval", b"interval", "name", b"name", "resource_info", b"resource_info", "schema", b"schema", "sku", b"sku", "sync_database_id", b"sync_database_id", "use_private_link_connection", b"use_private_link_connection"]) -> None: ...

global___ServersDatabasesSyncGroups = ServersDatabasesSyncGroups

@typing_extensions.final
class SyncGroupSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MASTER_SYNC_MEMBER_NAME_FIELD_NUMBER: builtins.int
    TABLES_FIELD_NUMBER: builtins.int
    master_sync_member_name: builtins.str
    @property
    def tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SyncGroupSchemaTable]: ...
    def __init__(
        self,
        *,
        master_sync_member_name: builtins.str = ...,
        tables: collections.abc.Iterable[global___SyncGroupSchemaTable] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["master_sync_member_name", b"master_sync_member_name", "tables", b"tables"]) -> None: ...

global___SyncGroupSchema = SyncGroupSchema

@typing_extensions.final
class SyncGroupSchemaTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMNS_FIELD_NUMBER: builtins.int
    QUOTED_NAME_FIELD_NUMBER: builtins.int
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SyncGroupSchemaTableColumn]: ...
    quoted_name: builtins.str
    def __init__(
        self,
        *,
        columns: collections.abc.Iterable[global___SyncGroupSchemaTableColumn] | None = ...,
        quoted_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["columns", b"columns", "quoted_name", b"quoted_name"]) -> None: ...

global___SyncGroupSchemaTable = SyncGroupSchemaTable

@typing_extensions.final
class SyncGroupSchemaTableColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SIZE_FIELD_NUMBER: builtins.int
    DATA_TYPE_FIELD_NUMBER: builtins.int
    QUOTED_NAME_FIELD_NUMBER: builtins.int
    data_size: builtins.str
    data_type: builtins.str
    quoted_name: builtins.str
    def __init__(
        self,
        *,
        data_size: builtins.str = ...,
        data_type: builtins.str = ...,
        quoted_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_size", b"data_size", "data_type", b"data_type", "quoted_name", b"quoted_name"]) -> None: ...

global___SyncGroupSchemaTableColumn = SyncGroupSchemaTableColumn

@typing_extensions.final
class ServersDatabasesSecurityAlertPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLED_ALERTS_FIELD_NUMBER: builtins.int
    EMAIL_ACCOUNT_ADMINS_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def disabled_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_account_admins: builtins.bool
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_endpoint: builtins.str
    id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        disabled_alerts: collections.abc.Iterable[builtins.str] | None = ...,
        email_account_admins: builtins.bool = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_alerts", b"disabled_alerts", "email_account_admins", b"email_account_admins", "email_addresses", b"email_addresses", "id", b"id", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_endpoint", b"storage_endpoint", "type", b"type"]) -> None: ...

global___ServersDatabasesSecurityAlertPolicies = ServersDatabasesSecurityAlertPolicies

@typing_extensions.final
class ServersDatabasesSchemasTablesColumnsSensitivityLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    INFORMATION_TYPE_FIELD_NUMBER: builtins.int
    INFORMATION_TYPE_ID_FIELD_NUMBER: builtins.int
    LABEL_ID_FIELD_NUMBER: builtins.int
    LABEL_NAME_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    information_type: builtins.str
    information_type_id: builtins.str
    label_id: builtins.str
    label_name: builtins.str
    rank: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        information_type: builtins.str = ...,
        information_type_id: builtins.str = ...,
        label_id: builtins.str = ...,
        label_name: builtins.str = ...,
        rank: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["information_type", b"information_type", "information_type_id", b"information_type_id", "label_id", b"label_id", "label_name", b"label_name", "name", b"name", "rank", b"rank", "resource_info", b"resource_info"]) -> None: ...

global___ServersDatabasesSchemasTablesColumnsSensitivityLabels = ServersDatabasesSchemasTablesColumnsSensitivityLabels

@typing_extensions.final
class ServersDatabasesMaintenanceWindows(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIME_RANGES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def time_ranges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTimeRange]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        time_ranges: collections.abc.Iterable[global___MaintenanceWindowTimeRange] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "time_ranges", b"time_ranges"]) -> None: ...

global___ServersDatabasesMaintenanceWindows = ServersDatabasesMaintenanceWindows

@typing_extensions.final
class MaintenanceWindowTimeRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    day_of_week: builtins.str
    duration: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        day_of_week: builtins.str = ...,
        duration: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week", "duration", b"duration", "start_time", b"start_time"]) -> None: ...

global___MaintenanceWindowTimeRange = MaintenanceWindowTimeRange

@typing_extensions.final
class ServersDatabasesLedgerDigestUploads(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DIGEST_STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    digest_storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        digest_storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["digest_storage_endpoint", b"digest_storage_endpoint", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersDatabasesLedgerDigestUploads = ServersDatabasesLedgerDigestUploads

@typing_extensions.final
class ServersDatabasesExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_PASSWORD_FIELD_NUMBER: builtins.int
    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    DATABASE_EDITION_FIELD_NUMBER: builtins.int
    MAX_SIZE_BYTES_FIELD_NUMBER: builtins.int
    NETWORK_ISOLATION_FIELD_NUMBER: builtins.int
    OPERATION_MODE_FIELD_NUMBER: builtins.int
    SERVICE_OBJECTIVE_NAME_FIELD_NUMBER: builtins.int
    STORAGE_KEY_FIELD_NUMBER: builtins.int
    STORAGE_KEY_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    administrator_login: builtins.str
    administrator_login_password: builtins.str
    authentication_type: builtins.str
    database_edition: builtins.str
    max_size_bytes: builtins.str
    @property
    def network_isolation(self) -> global___NetworkIsolationSettings: ...
    operation_mode: builtins.str
    service_objective_name: builtins.str
    storage_key: builtins.str
    storage_key_type: builtins.str
    storage_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        administrator_login: builtins.str = ...,
        administrator_login_password: builtins.str = ...,
        authentication_type: builtins.str = ...,
        database_edition: builtins.str = ...,
        max_size_bytes: builtins.str = ...,
        network_isolation: global___NetworkIsolationSettings | None = ...,
        operation_mode: builtins.str = ...,
        service_objective_name: builtins.str = ...,
        storage_key: builtins.str = ...,
        storage_key_type: builtins.str = ...,
        storage_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_isolation", b"network_isolation", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_login", b"administrator_login", "administrator_login_password", b"administrator_login_password", "authentication_type", b"authentication_type", "database_edition", b"database_edition", "max_size_bytes", b"max_size_bytes", "name", b"name", "network_isolation", b"network_isolation", "operation_mode", b"operation_mode", "resource_info", b"resource_info", "service_objective_name", b"service_objective_name", "storage_key", b"storage_key", "storage_key_type", b"storage_key_type", "storage_uri", b"storage_uri"]) -> None: ...

global___ServersDatabasesExtensions = ServersDatabasesExtensions

@typing_extensions.final
class NetworkIsolationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_SERVER_RESOURCE_ID_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_RESOURCE_ID_FIELD_NUMBER: builtins.int
    sql_server_resource_id: builtins.str
    storage_account_resource_id: builtins.str
    def __init__(
        self,
        *,
        sql_server_resource_id: builtins.str = ...,
        storage_account_resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sql_server_resource_id", b"sql_server_resource_id", "storage_account_resource_id", b"storage_account_resource_id"]) -> None: ...

global___NetworkIsolationSettings = NetworkIsolationSettings

@typing_extensions.final
class ServersDatabasesExtendedAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUDIT_ACTIONS_AND_GROUPS_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    IS_STORAGE_SECONDARY_KEY_IN_USE_FIELD_NUMBER: builtins.int
    PREDICATE_EXPRESSION_FIELD_NUMBER: builtins.int
    QUEUE_DELAY_MS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def audit_actions_and_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_azure_monitor_target_enabled: builtins.bool
    is_storage_secondary_key_in_use: builtins.bool
    predicate_expression: builtins.str
    queue_delay_ms: builtins.int
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        audit_actions_and_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        is_storage_secondary_key_in_use: builtins.bool = ...,
        predicate_expression: builtins.str = ...,
        queue_delay_ms: builtins.int = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_actions_and_groups", b"audit_actions_and_groups", "is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "is_storage_secondary_key_in_use", b"is_storage_secondary_key_in_use", "name", b"name", "predicate_expression", b"predicate_expression", "queue_delay_ms", b"queue_delay_ms", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersDatabasesExtendedAuditingSettings = ServersDatabasesExtendedAuditingSettings

@typing_extensions.final
class ServersDatabasesBackupShortTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DIFF_BACKUP_INTERVAL_IN_HOURS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    diff_backup_interval_in_hours: builtins.int
    retention_days: builtins.int
    id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        diff_backup_interval_in_hours: builtins.int = ...,
        retention_days: builtins.int = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["diff_backup_interval_in_hours", b"diff_backup_interval_in_hours", "id", b"id", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "type", b"type"]) -> None: ...

global___ServersDatabasesBackupShortTermRetentionPolicies = ServersDatabasesBackupShortTermRetentionPolicies

@typing_extensions.final
class ServersDatabasesBackupLongTermRetentionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MONTHLY_RETENTION_FIELD_NUMBER: builtins.int
    WEEKLY_RETENTION_FIELD_NUMBER: builtins.int
    WEEK_OF_YEAR_FIELD_NUMBER: builtins.int
    YEARLY_RETENTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    monthly_retention: builtins.str
    weekly_retention: builtins.str
    week_of_year: builtins.int
    yearly_retention: builtins.str
    id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        monthly_retention: builtins.str = ...,
        weekly_retention: builtins.str = ...,
        week_of_year: builtins.int = ...,
        yearly_retention: builtins.str = ...,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "monthly_retention", b"monthly_retention", "name", b"name", "resource_info", b"resource_info", "type", b"type", "week_of_year", b"week_of_year", "weekly_retention", b"weekly_retention", "yearly_retention", b"yearly_retention"]) -> None: ...

global___ServersDatabasesBackupLongTermRetentionPolicies = ServersDatabasesBackupLongTermRetentionPolicies

@typing_extensions.final
class ServersDatabasesAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUDIT_ACTIONS_AND_GROUPS_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    IS_STORAGE_SECONDARY_KEY_IN_USE_FIELD_NUMBER: builtins.int
    QUEUE_DELAY_MS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    IS_MANAGED_IDENTITY_IN_USE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def audit_actions_and_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_azure_monitor_target_enabled: builtins.bool
    is_storage_secondary_key_in_use: builtins.bool
    queue_delay_ms: builtins.int
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    kind: builtins.str
    is_managed_identity_in_use: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        audit_actions_and_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        is_storage_secondary_key_in_use: builtins.bool = ...,
        queue_delay_ms: builtins.int = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
        kind: builtins.str = ...,
        is_managed_identity_in_use: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_actions_and_groups", b"audit_actions_and_groups", "id", b"id", "is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "is_managed_identity_in_use", b"is_managed_identity_in_use", "is_storage_secondary_key_in_use", b"is_storage_secondary_key_in_use", "kind", b"kind", "name", b"name", "queue_delay_ms", b"queue_delay_ms", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersDatabasesAuditingSettings = ServersDatabasesAuditingSettings

@typing_extensions.final
class ServersDatabases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_PAUSE_DELAY_FIELD_NUMBER: builtins.int
    CATALOG_COLLATION_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    CREATE_MODE_FIELD_NUMBER: builtins.int
    ELASTIC_POOL_ID_FIELD_NUMBER: builtins.int
    FEDERATED_CLIENT_ID_FIELD_NUMBER: builtins.int
    HIGH_AVAILABILITY_REPLICA_COUNT_FIELD_NUMBER: builtins.int
    IS_LEDGER_ON_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    LONG_TERM_RETENTION_BACKUP_RESOURCE_ID_FIELD_NUMBER: builtins.int
    MAINTENANCE_CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    MAX_SIZE_BYTES_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    PRIMARY_DELEGATED_IDENTITY_CLIENT_ID_FIELD_NUMBER: builtins.int
    READ_SCALE_FIELD_NUMBER: builtins.int
    RECOVERABLE_DATABASE_ID_FIELD_NUMBER: builtins.int
    RECOVERY_SERVICES_RECOVERY_POINT_ID_FIELD_NUMBER: builtins.int
    REQUESTED_BACKUP_STORAGE_REDUNDANCY_FIELD_NUMBER: builtins.int
    RESTORABLE_DROPPED_DATABASE_ID_FIELD_NUMBER: builtins.int
    RESTORE_POINT_IN_TIME_FIELD_NUMBER: builtins.int
    SAMPLE_NAME_FIELD_NUMBER: builtins.int
    SECONDARY_TYPE_FIELD_NUMBER: builtins.int
    SOURCE_DATABASE_DELETION_DATE_FIELD_NUMBER: builtins.int
    SOURCE_DATABASE_ID_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_LEDGER_DIGEST_UPLOADS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_MAINTENANCE_WINDOWS_FIELD_NUMBER: builtins.int
    SERVERS_DATABASES_WORKLOAD_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___DatabaseIdentity: ...
    location: builtins.str
    name: builtins.str
    auto_pause_delay: builtins.int
    catalog_collation: builtins.str
    collation: builtins.str
    create_mode: builtins.str
    elastic_pool_id: builtins.str
    federated_client_id: builtins.str
    high_availability_replica_count: builtins.int
    is_ledger_on: builtins.bool
    license_type: builtins.str
    long_term_retention_backup_resource_id: builtins.str
    maintenance_configuration_id: builtins.str
    max_size_bytes: builtins.int
    min_capacity: builtins.float
    primary_delegated_identity_client_id: builtins.str
    read_scale: builtins.str
    recoverable_database_id: builtins.str
    recovery_services_recovery_point_id: builtins.str
    requested_backup_storage_redundancy: builtins.str
    restorable_dropped_database_id: builtins.str
    restore_point_in_time: builtins.str
    sample_name: builtins.str
    secondary_type: builtins.str
    source_database_deletion_date: builtins.str
    source_database_id: builtins.str
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def servers_databases_ledger_digest_uploads(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesLedgerDigestUploads]: ...
    @property
    def servers_databases_maintenance_windows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesMaintenanceWindows]: ...
    @property
    def servers_databases_workload_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDatabasesWorkloadGroups]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___DatabaseIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        auto_pause_delay: builtins.int = ...,
        catalog_collation: builtins.str = ...,
        collation: builtins.str = ...,
        create_mode: builtins.str = ...,
        elastic_pool_id: builtins.str = ...,
        federated_client_id: builtins.str = ...,
        high_availability_replica_count: builtins.int = ...,
        is_ledger_on: builtins.bool = ...,
        license_type: builtins.str = ...,
        long_term_retention_backup_resource_id: builtins.str = ...,
        maintenance_configuration_id: builtins.str = ...,
        max_size_bytes: builtins.int = ...,
        min_capacity: builtins.float = ...,
        primary_delegated_identity_client_id: builtins.str = ...,
        read_scale: builtins.str = ...,
        recoverable_database_id: builtins.str = ...,
        recovery_services_recovery_point_id: builtins.str = ...,
        requested_backup_storage_redundancy: builtins.str = ...,
        restorable_dropped_database_id: builtins.str = ...,
        restore_point_in_time: builtins.str = ...,
        sample_name: builtins.str = ...,
        secondary_type: builtins.str = ...,
        source_database_deletion_date: builtins.str = ...,
        source_database_id: builtins.str = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        servers_databases_ledger_digest_uploads: collections.abc.Iterable[global___ServersDatabasesLedgerDigestUploads] | None = ...,
        servers_databases_maintenance_windows: collections.abc.Iterable[global___ServersDatabasesMaintenanceWindows] | None = ...,
        servers_databases_workload_groups: collections.abc.Iterable[global___ServersDatabasesWorkloadGroups] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_pause_delay", b"auto_pause_delay", "catalog_collation", b"catalog_collation", "collation", b"collation", "create_mode", b"create_mode", "elastic_pool_id", b"elastic_pool_id", "federated_client_id", b"federated_client_id", "high_availability_replica_count", b"high_availability_replica_count", "identity", b"identity", "is_ledger_on", b"is_ledger_on", "license_type", b"license_type", "location", b"location", "long_term_retention_backup_resource_id", b"long_term_retention_backup_resource_id", "maintenance_configuration_id", b"maintenance_configuration_id", "max_size_bytes", b"max_size_bytes", "min_capacity", b"min_capacity", "name", b"name", "primary_delegated_identity_client_id", b"primary_delegated_identity_client_id", "read_scale", b"read_scale", "recoverable_database_id", b"recoverable_database_id", "recovery_services_recovery_point_id", b"recovery_services_recovery_point_id", "requested_backup_storage_redundancy", b"requested_backup_storage_redundancy", "resource_info", b"resource_info", "restorable_dropped_database_id", b"restorable_dropped_database_id", "restore_point_in_time", b"restore_point_in_time", "sample_name", b"sample_name", "secondary_type", b"secondary_type", "servers_databases_ledger_digest_uploads", b"servers_databases_ledger_digest_uploads", "servers_databases_maintenance_windows", b"servers_databases_maintenance_windows", "servers_databases_workload_groups", b"servers_databases_workload_groups", "sku", b"sku", "source_database_deletion_date", b"source_database_deletion_date", "source_database_id", b"source_database_id", "tags", b"tags", "zone_redundant", b"zone_redundant"]) -> None: ...

global___ServersDatabases = ServersDatabases

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    family: builtins.str
    name: builtins.str
    size: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        family: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "family", b"family", "name", b"name", "size", b"size", "tier", b"tier"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class DatabaseIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DelegatedResourcesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DELEGATED_RESOURCES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    @property
    def delegated_resources(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        delegated_resources: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegated_resources", b"delegated_resources", "type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___DatabaseIdentity = DatabaseIdentity
